pub struct DeclareHashes {
pub optout: bool,
pub hashes: Vec<Vec<u8>>,
pub mode: i32,
pub exists: bool,
}Expand description
Used for avoiding retransmitting messages already on remote peer. yes I am aware i should have used a merkle tree. I was sleepy.
Fields
optout: boolScatterType type = 1;
hashes: Vec<Vec<u8>>mode: i32exists: boolImplementations
Sourceimpl DeclareHashes
impl DeclareHashes
Sourcepub fn mode(&self) -> DeclareHashesMode
pub fn mode(&self) -> DeclareHashesMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: DeclareHashesMode)
pub fn set_mode(&mut self, value: DeclareHashesMode)
Sets mode to the provided enum value.